You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by dj...@apache.org on 2007/01/13 03:18:24 UTC

svn commit: r495819 - in /db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests: UpgradeRun.java _Suite.java

Author: djd
Date: Fri Jan 12 18:18:23 2007
New Revision: 495819

URL: http://svn.apache.org/viewvc?view=rev&rev=495819
Log:
DERBY-2217 (partial) Change the property used to locate the old releases to
be 'derbyTesting.oldReleasePath' for the new Junit upgrade test. This is
clearer than the name of the older property for the harness based test and
will allow the tests to be run in parallel while the new junit test is
catching up to all the testing provided by the old one.

Modified:
    db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/UpgradeRun.java
    db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/_Suite.java

Modified: db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/UpgradeRun.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/UpgradeRun.java?view=diff&rev=495819&r1=495818&r2=495819
==============================================================================
--- db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/_Suite.java (original)
+++ db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/_Suite.java Fri Jan 12 18:18:23 2007
@@ -66,6 +66,13 @@
 public class _Suite extends BaseTestCase {
     
     /**
+     * Property that indicates the location of the
+     * old releases.
+     */
+    static final String OLD_RELEASE_PATH_PROPERTY =
+        "derbyTesting.oldReleasePath";
+    
+    /**
      * List of the versions to test against.
      * The tests look for the jar files in each releasae
      * in the folder:
@@ -97,9 +104,10 @@
     
     public static Test suite() {
         
-        if (getSystemProperty("derbyTesting.jar.path") == null)
+        if (getSystemProperty(OLD_RELEASE_PATH_PROPERTY) == null)
             return new TestSuite(
-                    "empty: no upgrade tests: derbyTesting.jar.path not set");
+                    "empty: no upgrade tests: " +
+                    OLD_RELEASE_PATH_PROPERTY + " not set");
         
         TestSuite suite = new TestSuite("Upgrade Suite");
--- db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/UpgradeRun.java (original)
+++ db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/UpgradeRun.java Fri Jan 12 18:18:23 2007
@@ -170,14 +170,15 @@
     
     /**
      * Get the location of jars of old release. The location is specified 
      * in the property "derbyTesting.jar.path".
      *  
      * @return location of jars of old release
      */
     private static String getOldJarLocation(int[] oldVersion) {
-        String jarPath = System.getProperty("derbyTesting.jar.path");
+        String jarPath = System.getProperty(_Suite.OLD_RELEASE_PATH_PROPERTY);
         
-        Assert.assertNotNull("derbyTesting.jar.path not set", jarPath);
+        Assert.assertNotNull(_Suite.OLD_RELEASE_PATH_PROPERTY
+                + " not set", jarPath);
       
         String version = getTextVersion(oldVersion);
         String jarLocation = jarPath + File.separator + version
@@ -200,7 +201,7 @@
         String jarLocation = getOldJarLocation(version);
         
         File lib = new File(jarLocation);
-        
+                
         // If the jars do not exist then return null
         // and the caller will set up to skip this.
         if (!lib.exists())
@@ -170,14 +170,15 @@
     /**
      * Get the location of jars of old release. The location is specified 
-     * in the property "derbyTesting.jar.path".
+     * in the property derbyTesting.oldReleasePath.
      *  
      * @return location of jars of old release

Modified: db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/_Suite.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/upgradeTests/_Suite.java?view=diff&rev=495819&r1=495818&r2=495819
==============================================================================